# Advanced Weighting Systems

**DOI**: [10.5281/zenodo.19110330](https://doi.org/10.5281/zenodo.19110330)
**Zenodo**: [https://zenodo.org/records/19110330](https://zenodo.org/records/19110330)

[![PyPI version](https://badge.fury.io/py/advanced-weighting-systems.svg)](https://pypi.org/project/advanced-weighting-systems/)
[![Zenodo DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.19110330.svg)](https://doi.org/10.5281/zenodo.19110330)
[![Tests](https://github.com/GenesisAeon/AdvancedWeightingSystems/actions/workflows/release.yml/badge.svg)](https://github.com/GenesisAeon/AdvancedWeightingSystems/actions)

Resonance-based, symbolically mirrored coupling of heterogeneous neural network models
within the **AeonLayer** for AeonAI — the GenesisAeon project.

See [Reference](reference.md) for full mathematical documentation.
